@@ -1,6 +1,7 @@
+use std::hash::Hash;
 use std::marker::PhantomData;
 
-pub trait IdLike: Copy+Ord+PartialEq+'static {
+pub trait IdLike: Copy+Hash+Ord+PartialEq+'static {
     // named to avoid stepping on other libraries etc
     fn id_min_value() -> Self;
     fn id_max_value() -> Self;
@@ -83,6 +84,12 @@ impl<T> std::fmt::Debug for Id<T> {
     }
 }
 
+impl<T> Hash for Id<T> {
+    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
+        self.0.hash(state);
+    }
+}
+
 impl<T> PartialEq for Id<T> {
     fn eq(&self, id2: &Id<T>) -> bool {
         self.0 == id2.0
