@@ -8,4 +8,7 @@ pub mod many_to_many;
 pub use one_to_one::RawOneToOne;
 pub use one_to_many::RawOneToMany;
 pub use many_to_one::RawManyToOne;
-pub use many_to_many::RawManyToMany;
\ No newline at end of file
+pub use many_to_many::RawManyToMany;
+
+#[cfg(feature="serde1")]
+mod serde_impl;
\ No newline at end of file
