@@ -9,4 +9,7 @@ pub mod to_many;
 
 pub use set::RawSet;
 pub use to_one::RawToOne;
-pub use to_many::RawToMany;
\ No newline at end of file
+pub use to_many::RawToMany;
+
+#[cfg(feature="serde1")]
+mod serde_impl;
\ No newline at end of file
