@@ -1,6 +1,9 @@
 mod backward;
 mod forward;
 mod structure;
+mod extra;
+mod fwd_set_extra;
+mod bwd_set_extra;
 
 pub use self::structure::ManyToMany;
 pub use self::forward::{Fwd, FwdSet};
