@@ -1,6 +1,8 @@
 mod backward;
 mod forward;
 mod structure;
+mod extra;
+mod bwd_set_extra;
 
 pub use self::structure::ManyToOne;
 pub use self::forward::Fwd;
