@@ -7,6 +7,9 @@ mod debug_impl;
 #[cfg(feature="serde1")]
 mod serde_impl;
 
+mod extra;
+
+#[derive(Clone)]
 pub struct Pom<T: 'static> { 
     index: Set<Id<T>>,
     elements: RawPom<T>,
@@ -20,6 +23,7 @@ impl<T: 'static> Pom<T> {
         }
     }
 
+    #[cfg(feature="serde1")]  // only needs to exist for serde
     pub(crate) fn from_raw(elements: RawPom<T>) -> Self {
         let index = Set::new();
         for k in elements.keys() { index.fwd().insert(k); }
