@@ -6,4 +6,7 @@ pub mod to_many;
 
 pub use set::Set;
 pub use to_one::ToOne;
-pub use to_many::ToMany;
\ No newline at end of file
+pub use to_many::ToMany;
+
+#[cfg(feature="serde1")]
+mod serde_impl;
\ No newline at end of file
